==> 0.0.1%2B1.tar.gz: lib/models/IR5Route.dart <==
import 'package:json_annotation/json_annotation.dart';

import "IR5Route2PtrLnk.dart" show IR5Route2PtrLnk;

// --------------------------------------------------------------------------------
part 'IR5Route.g.dart';

/** Logical Destination aka Route */
@JsonSerializable(explicitToJson: true)
class IR5Route {
  IR5Route({
    required this.Num,
    required this.NomLogique,
    required this.Flags,
    required this.Description,
    required this.RecapList,
    required this.Ptr,
    required this.PtrLinks,
  });

  factory IR5Route.fromJson(Map<String, dynamic>? json) => _$IR5RouteFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5RouteToJson(this);

  /** Destination aka Route
   * PLU Destination limited to the first 1..16
   */
  @JsonKey(defaultValue: 0)
  final num Num;

  /** NOMLOGIQUE */
  @JsonKey(defaultValue: '')
  final String NomLogique;

  /** Desti/Route Flags
   *   Bit 00 : PureLogique
   *   Bit 01 : Disabled
   *   Bit 02 : ShowRouteNameOnTicket
   *   Bit 10 : WantSepConso
   *   Bit 11 : WantSuite
   *   Bit 12 : WantTft
   *   Bit 13 : WantMx
   *   Bit 14 : IgnoreConsoPos
   *   Bit 15 : IgnoreConsoNeg
   *   Bit 20 : MsgRed
   *   Bit 21 : NegatifRed
   *   Bit 22 : PizzaRed
   *   Bit 23 : ActionRed
   *   Bit 29 : Palier2x
   *   Bit 30 : PalierClassic
   *   Bit 31 : TicketParSep
   *   Bit 39 : GroupByMenuLvl
   *   Bit 40 : GroupByDesti
   *   Bit 41 : GroupByCateg
   *   Bit 42 : ModeEtiquette
   *   Bit 43 : ModeEtiquetteByQty
   *   Bit 45 : ShowGroupName
   *   Bit 59 : NoDelayedTicketProd
   */
  @JsonKey(defaultValue: 0)
  final num Flags;

  /** Just a free Description */
  @JsonKey(defaultValue: '')
  final String Description;

  /** RECAPLIST */
  @JsonKey(defaultValue: '')
  final String RecapList;

  /** Default Printer iff not defined in Station Printer Links (Ptrs_DEF) */
  @JsonKey(defaultValue: 0)
  final num Ptr;
  @JsonKey(defaultValue: [])
  final List<IR5Route2PtrLnk> PtrLinks;
}

==> 0.0.2%2B1.tar.gz: lib/models/IR5Route.dart <==
import 'package:json_annotation/json_annotation.dart';

import "IR5Route2PtrLnk.dart" show IR5Route2PtrLnk;

// --------------------------------------------------------------------------------
part 'IR5Route.g.dart';

/** Logical Destination aka Route */
@JsonSerializable(explicitToJson: true)
class IR5Route {
  IR5Route({
    required this.Num,
    required this.NomLogique,
    required this.Flags,
    required this.Description,
    required this.RecapList,
    required this.Ptr,
    required this.PtrLinks,
  });

  factory IR5Route.fromJson(Map<String, dynamic>? json) =>
      _$IR5RouteFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5RouteToJson(this);

  /** Destination aka Route
   * PLU Destination limited to the first 1..16
   */
  @JsonKey(defaultValue: 0)
  final num Num;

  /** NOMLOGIQUE */
  @JsonKey(defaultValue: '')
  final String NomLogique;

  /** Desti/Route Flags
   *   Bit 00 : PureLogique
   *   Bit 01 : Disabled
   *   Bit 02 : ShowRouteNameOnTicket
   *   Bit 10 : WantSepConso
   *   Bit 11 : WantSuite
   *   Bit 12 : WantTft
   *   Bit 13 : WantMx
   *   Bit 14 : IgnoreConsoPos
   *   Bit 15 : IgnoreConsoNeg
   *   Bit 20 : MsgRed
   *   Bit 21 : NegatifRed
   *   Bit 22 : PizzaRed
   *   Bit 23 : ActionRed
   *   Bit 29 : Palier2x
   *   Bit 30 : PalierClassic
   *   Bit 31 : TicketParSep
   *   Bit 39 : GroupByMenuLvl
   *   Bit 40 : GroupByDesti
   *   Bit 41 : GroupByCateg
   *   Bit 42 : ModeEtiquette
   *   Bit 43 : ModeEtiquetteByQty
   *   Bit 45 : ShowGroupName
   *   Bit 59 : NoDelayedTicketProd
   */
  @JsonKey(defaultValue: 0)
  final num Flags;

  /** Just a free Description */
  @JsonKey(defaultValue: '')
  final String Description;

  /** RECAPLIST */
  @JsonKey(defaultValue: '')
  final String RecapList;

  /** Default Printer iff not defined in Station Printer Links (Ptrs_DEF) */
  @JsonKey(defaultValue: 0)
  final num Ptr;
  @JsonKey(defaultValue: [])
  final List<IR5Route2PtrLnk> PtrLinks;
}
